==> mls-0.3.tar.gz: mls-0.3/src/panel_select.cpp <==
///	\file	panel_select.cpp
///	\brief	panel_select.cpp
#include <dirent.h>
#include <sys/stat.h>
#include <unistd.h>
#include <vector>
#include <stack>

#include "panel.h"

using namespace std;
using namespace MLS;

///	\brief	선택된 파일 목록을 가져오는 함수
///
/// 내부static 변수를 리턴함 쓰레드에 대해서 안전하지 않음
/// 가져온 스트링의 마지막이 / 로 끝나면 디렉토리 입니다.
/// zip 파일일때는 bDirExpansion은 true가 되선 않된다.
///
///	\param	size			파일 목록 개수(반환값)
///	\param	bDirExpansion	Directory 확장여부
///	\return	선택된 파일 목록
Selection Panel::GetSelection( )
{
	Selection ret;
	
	if (sel_num == 0)
	{
		if (file_list[cur]->name != "..")
		{
			if (m_nZip == 0)
			{
				if (file_list[cur]->bDir)
				{
					ret.Add(file_list[cur]->name + '/');
				}
				else
				{
					ret.Add(file_list[cur]->name);
				}
			}
			else
			{
				// zip 이면 FullName을 넣는다. 
				ret.Add(file_list[cur]->FullName);
			}
		}
	}
	else	
	{
		for (pFileIterator i= file_list.begin(); i!=file_list.end(); ++i)
		{
			if ((*i)->selected)
			{
				if (m_nZip == 0)
				{
					if ((*i)->bDir)
						ret.Add((*i)->name + '/');
					else 
						ret.Add((*i)->name);
					
				}
				else
				{
					// zip 이면 FullName을 넣는다. 
					ret.Add((*i)->FullName);
					if (!(*i)->bDir)
					{
						//size += (*i)->size;
					}
				}
			}
		}
	}
	ret.SetBaseDir(path);
	
	return ret;
}

///	\brief	파일을 선택한다.(반전 시킴)
///	\param	f	선택할 파일
void Panel::select(File &f)
{
	if (f.name == "..") return;	
	if (f.selected) return;
	// 인덱스를 저장
	f.selected = true;	
	sel_size += f.size;	
	sel_num++;
}

///	\brief	파일선택을 해제한다.
///	\param	f	선택 해제할 파일
void Panel::deselect(File &f)
{
	if (!f.selected) return;
	f.selected = false;
	sel_size -= f.size;	
	sel_num--;		
}

==> mls-0.4.tar.gz: mls-0.4/src/panel_select.cpp <==
///	\file	panel_select.cpp
///	\brief	panel_select.cpp
#include <dirent.h>
#include <sys/stat.h>
#include <unistd.h>
#include <vector>
#include <stack>

#include "panel.h"

using namespace std;
using namespace MLS;

///	\brief	선택된 파일 목록을 가져오는 함수
///
/// 내부static 변수를 리턴함 쓰레드에 대해서 안전하지 않음
/// 가져온 스트링의 마지막이 / 로 끝나면 디렉토리 입니다.
/// zip 파일일때는 bDirExpansion은 true가 되선 않된다.
///
///	\param	size			파일 목록 개수(반환값)
///	\param	bDirExpansion	Directory 확장여부
///	\return	선택된 파일 목록
Selection Panel::GetSelection( )
{
	Selection ret;
	
	if (sel_num == 0)
	{
		if (file_list[cur]->name != "..")
		{
			if (m_nZip == 0)
			{
				if (file_list[cur]->bDir)
				{
					ret.Add(file_list[cur]->name + '/');
				}
				else
				{
					ret.Add(file_list[cur]->name);
				}
			}
			else
			{
				// zip 이면 FullName을 넣는다. 
				ret.Add(file_list[cur]->FullName);
			}
		}
	}
	else	
	{
		vector<string> directories;
		
		for (pFileIterator i= file_list.begin(); i!=file_list.end(); ++i)
		{
			if ((*i)->selected)
			{
				if (m_nZip == 0)
				{
					if ((*i)->bDir)
						directories.push_back((*i)->name + '/');
					else 
						ret.Add((*i)->name);					
				}
				else
				{
					// zip 이면 FullName을 넣는다. 
					ret.Add((*i)->FullName);
					if (!(*i)->bDir)
					{
						//size += (*i)->size;
					}
				}
			}
		}
		
		for (int t=0; t<directories.size(); t++)
		{
			ret.Add(directories[t]);			
		}		
	}
	ret.SetBaseDir(path);
	
	return ret;
}

///	\brief	파일을 선택한다.(반전 시킴)
///	\param	f	선택할 파일
void Panel::select(File &f)
{
	if (f.name == "..") return;	
	if (f.selected) return;
	// 인덱스를 저장
	f.selected = true;	
	sel_size += f.size;	
	sel_num++;
}

///	\brief	파일선택을 해제한다.
///	\param	f	선택 해제할 파일
void Panel::deselect(File &f)
{
	if (!f.selected) return;
	f.selected = false;
	sel_size -= f.size;	
	sel_num--;		
}
